/**
 * An annotated JSDoc block tag, all fields are optionally processed except for
 * the tag:
 *
 *     @TAG {TYPE} NAME DESC
 */
export interface Tag {
    tag: string;
    type: string | null;
    name: string | null;
    description: string | null;
}
/**
 * The parsed representation of a JSDoc comment.
 */
export interface Annotation {
    description?: string;
    tags: Tag[] | null;
}
/**
 * removes leading *, and any space before it
 */
export declare function removeLeadingAsterisks(description: string): string;
/**
 * Given a JSDoc string (minus opening/closing comment delimiters), extract its
 * description and tags.
 *
 * @param {string} docs
 * @return {?Annotation}
 */
export declare function parseJsdoc(docs: string): Annotation;
export declare function hasTag(jsdoc: Annotation | null | undefined, tagName: string): boolean;
/**
 * Finds the first JSDoc tag matching `name` and returns its value at `key`.
 *
 * If `key` is omitted, the entire tag object is returned.
 */
export declare function getTag(jsdoc: Annotation | null | undefined, tagName: string): (Tag | null);
export declare function getTag(jsdoc: Annotation | null | undefined, tagName: string, key: string): (string | null);
export declare function unindent(text: string): string;
